@@ -1,14 +1,21 @@
 ergm.pl<-function(Clist, Clist.miss=NULL, m, theta.offset=NULL,
-                    maxMPLEsamplesize=100000,
-                    maxNumDyadTypes=100000,
-                    verbose=FALSE) {
+                    maxMPLEsamplesize=1e+6,
+                    maxNumDyadTypes=1e+6,
+                    verbose=FALSE,
+                    compressflag=TRUE) {
   offset <- rep(0,Clist$ndyads)
-  numobs <- Clist$ndyads
+  bip <- Clist$bipartite
+  n <- Clist$n
+  maxNumDyadTypes <- min(maxNumDyadTypes,
+                         ifelse(bip>0, bip*(n-bip), 
+                                ifelse(Clist$dir, n*(n-1), n*(n-1)/2)))
+  # May have to think harder about what maxNumDyadTypes should be if we 
+  # implement a hash-table approach to compression.  
   z <- .C("MPLE_wrapper",
           as.integer(Clist$heads),    as.integer(Clist$tails),
           as.integer(Clist$nedges), as.integer(Clist$maxpossibleedges),
-          as.integer(Clist$n), 
-          as.integer(Clist$dir),     as.integer(Clist$bipartite),
+          as.integer(n), 
+          as.integer(Clist$dir),     as.integer(bip),
           as.integer(Clist$nterms), 
           as.character(Clist$fnamestring), as.character(Clist$snamestring),
           as.double(Clist$inputs),
@@ -18,8 +25,13 @@ ergm.pl<-function(Clist, Clist.miss=NULL, m, theta.offset=NULL,
           as.double(offset), compressedOffset=double(maxNumDyadTypes),
           as.integer(maxNumDyadTypes),
           as.integer(maxMPLEsamplesize),
+          as.integer(compressflag),
           PACKAGE="ergm")
   uvals <- z$weightsvector!=0
+  if (verbose) {
+    if (compressflag) cat("Compressed ")
+    cat(paste("MPLE covariate matrix has", sum(uvals), "rows.\n"))
+  }
   zy <- z$y[uvals]
   wend <- z$weightsvector[uvals]
   xmat <- matrix(z$x, ncol=Clist$nparam, byrow=TRUE)[uvals,,drop=FALSE]
